@@ -2,9 +2,10 @@
 # -*- coding:utf-8 -*-
 
 from flask import Flask
-from flask.ext.sqlalchemy import SQLAlchemy
-from flask.ext.script import Manager
-from flask.ext.migrate import Migrate, MigrateCommand
+from flask_sqlalchemy import SQLAlchemy
+from flask_script import Manager
+from flask_migrate import Migrate, MigrateCommand
+
 try:
     from django.conf import settings
 except ImportError:
@@ -12,6 +13,7 @@ except ImportError:
 
 app = Flask(__name__)
 app.config['SQLALCHEMY_DATABASE_URI'] = settings.ANTI_SQLALCHEMY_DATABASE_URI
+app.config['SQLALCHEMY_TRACK_MODIFICATIONS'] = True
 
 db = SQLAlchemy(app)
 migrate = Migrate(app, db)
@@ -20,29 +22,29 @@ manager = Manager(app)
 manager.add_command('db', MigrateCommand)
 
 class Key(db.Model):
-    id = db.Column(db.Integer, primary_key = True)
+    id = db.Column(db.Integer, primary_key=True)
     key = db.Column(db.String(255))
 
 class Host(db.Model):
-    id = db.Column(db.Integer, primary_key = True)
+    id = db.Column(db.Integer, primary_key=True)
     host = db.Column(db.String(255))
 
 class Url(db.Model):
-    id = db.Column(db.Integer, primary_key = True)
+    id = db.Column(db.Integer, primary_key=True)
     url = db.Column(db.String(1023))
 
 class Pos(db.Model):
-    id = db.Column(db.BigInteger, primary_key = True)
+    id = db.Column(db.BigInteger, primary_key=True)
     date = db.Column(db.Date)
     key_id = db.Column(db.Integer, db.ForeignKey('key.id'))
     host_id = db.Column(db.Integer, db.ForeignKey('host.id'))
     url_id = db.Column(db.Integer, db.ForeignKey('url.id'))
     pos = db.Column(db.SmallInteger)
     search = db.Column(db.SmallInteger)
-    lr = db.Column(db.SmallInteger, default = 213)
+    lr = db.Column(db.SmallInteger, default=213)
 
 class SeoData(db.Model):
-    id = db.Column(db.Integer, primary_key = True)
+    id = db.Column(db.Integer, primary_key=True)
     date = db.Column(db.Date)
     host_id = db.Column(db.Integer, db.ForeignKey('host.id'))
     tic = db.Column(db.SmallInteger)
@@ -57,7 +59,7 @@ class SeoData(db.Model):
     wm_indexed = db.Column(db.Integer)
 
 class Visits(db.Model):
-    id = db.Column(db.Integer, primary_key = True)
+    id = db.Column(db.Integer, primary_key=True)
     date = db.Column(db.Date)
     host_id = db.Column(db.Integer, db.ForeignKey('host.id'))
     av = db.Column(db.Integer)
@@ -65,7 +67,7 @@ class Visits(db.Model):
     sv = db.Column(db.Integer)
 
 class Token(db.Model):
-    id = db.Column(db.Integer, primary_key = True)
+    id = db.Column(db.Integer, primary_key=True)
     token = db.Column(db.String(255))
 
 if __name__ == '__main__':
